@@ -1,19 +1,25 @@
 # coding: utf-8
-from __future__ import absolute_import
-from __future__ import unicode_literals
 
-from importlib import import_module
+from importlib import (
+    import_module
+)
 import abc
 
-from django.conf import settings
-from six import with_metaclass
-
+from django.conf import (
+    settings
+)
 # нужно для импорта констант отсюда в barsdoc
 from m3_gar_constants import *
-from m3_gar_client.utils import cached_property
+
+from m3_gar_client.utils import (
+    cached_property
+)
 
 
-class Config(with_metaclass(abc.ABCMeta, object)):
+default_app_config = f'{__package__}.apps.AppConfig'
+
+
+class Config(abc.ABC):
 
     """Базовый класс для конфигурации пакета."""
 
