@@ -1,39 +1,31 @@
 # coding: utf-8
-from __future__ import (
-    absolute_import,
-    unicode_literals,
-)
-
 from abc import (
     ABCMeta,
-    abstractproperty,
+    abstractproperty
 )
 from collections import (
+    namedtuple
+)
+from collections.abc import (
     Mapping,
-    MutableMapping,
-    defaultdict,
-    namedtuple,
+    MutableMapping
 )
 from datetime import (
     date,
-    datetime,
+    datetime
 )
 from functools import (
-    partial,
+    partial
+)
+from typing import (
+    Dict
 )
 from uuid import (
-    UUID,
-)
-
-from six import (
-    iteritems,
-    iterkeys,
-    text_type,
-    with_metaclass,
+    UUID
 )
 
 from m3_gar_constants import (
-    GAR_LEVELS,
+    GAR_LEVELS
 )
 
 
@@ -67,7 +59,7 @@ class ObjectMeta(ABCMeta):
 
         fields = namespace['fields']
         if isinstance(fields, dict):
-            for field_name, field_descriptor in iteritems(fields):
+            for field_name, field_descriptor in fields.items():
                 setattr(cls, field_name, ReadOnlyAttribute(
                     name=field_name,
                     doc=field_descriptor.description,
@@ -76,21 +68,21 @@ class ObjectMeta(ABCMeta):
         return cls
 
 
-class ObjectBase(with_metaclass(ObjectMeta, object)):
-    """Базовый класс для объектов ГАР.
-
+class ObjectBase(metaclass=ObjectMeta):
+    """
+    Базовый класс для объектов ГАР.
     Обеспечивает неизменяемость данных (объекты только для чтения).
     """
 
     @abstractproperty
-    def fields(self):
+    def fields(self) -> Dict[str, FieldDescriptor]:
         """Описание полей объекта."""
 
     def __hash__(self):
         return hash(self.id)  # pylint: disable=no-member
 
     def __init__(self, **kwargs):
-        for field_name, field_descriptor in iteritems(self.fields):
+        for field_name, field_descriptor in self.fields.items():
             if field_descriptor.required:
                 if field_name in kwargs:
                     field_value = kwargs[field_name]
@@ -110,11 +102,15 @@ class ObjectBase(with_metaclass(ObjectMeta, object)):
 
 # dict в списке базовых классов нужен для правильной обработки данных в M3.
 class ObjectDictAdapter(Mapping, dict):
-    """Адаптер для объектов ГАР, преобразующий их к словарям."""
+    """
+    Адаптер для объектов ГАР, преобразующий их к словарям.
+    """
 
     def __init__(self, obj):  # pylint: disable=super-init-not-called
-        """Инициализация экземпляра класса."""
+        """Инициализация экземпляра класса.
 
+        :type obj: m3_gar_client.data.ObjectBase
+        """
         assert isinstance(obj, ObjectBase), type(obj)
 
         self._obj = obj
@@ -158,7 +154,7 @@ class ObjectDictAdapter(Mapping, dict):
 
 
 def _unicode(value):
-    return value if isinstance(value, text_type) else text_type(value)
+    return value if isinstance(value, str) else str(value)
 
 
 def _unicode_or_empty(value):
@@ -185,7 +181,7 @@ def _int_or_none(value):
 
 def _uuid(value):
     try:
-        return text_type(value if isinstance(value, UUID) else UUID(value))
+        return str(value if isinstance(value, UUID) else UUID(value))
     except (AttributeError, TypeError, ValueError):
         raise ValueError(value)
 
@@ -229,7 +225,9 @@ def _choices(valid_values, value_type, raw_value):
 
 
 class AddressObject(ObjectBase):
-    """Адресный объект."""
+    """
+    Адресный объект.
+    """
 
     #: Поля объекта и признак обязательности значения.
     fields = {
@@ -301,7 +299,9 @@ class AddressObject(ObjectBase):
         'kladr_plain_code': FieldDescriptor(
             data_type=_unicode_or_empty,
             required=False,
-            description='Код адресного объекта из КЛАДР 4.0 одной строкой без признака актуальности (последних двух цифр).',
+            description=(
+                'Код адресного объекта из КЛАДР 4.0 одной строкой без признака актуальности (последних двух цифр).'
+            ),
         ),
         'short_name': FieldDescriptor(
             data_type=_unicode,
@@ -382,7 +382,9 @@ class AddressObject(ObjectBase):
 
 
 class House(ObjectBase):
-    """Объект здания (дома)."""
+    """
+    Объект здания (дома).
+    """
 
     fields = {
         'id': FieldDescriptor(
@@ -490,11 +492,6 @@ class House(ObjectBase):
             required=False,
             description='Родительский guid в муниципальной иерархии'
         ),
-        'level': FieldDescriptor(
-            data_type=partial(_choices, GAR_LEVELS, _int),
-            required=True,
-            description='Уровень объекта.',
-        ),
         'number': FieldDescriptor(
             data_type=_int,
             required=False,
@@ -505,204 +502,30 @@ class House(ObjectBase):
             required=False,
             description=''
         ),
-        'house_type_full': FieldDescriptor(
-            data_type=_unicode_or_empty,
-            required=False,
-            description=''
-        ),
         'building_type': FieldDescriptor(
             data_type=_unicode_or_empty,
             required=False,
             description=''
         ),
-        'building_type_full': FieldDescriptor(
-            data_type=_unicode_or_empty,
-            required=False,
-            description=''
-        ),
         'structure_type': FieldDescriptor(
             data_type=_unicode_or_empty,
             required=False,
             description=''
         ),
-        'structure_type_full': FieldDescriptor(
-            data_type=_unicode_or_empty,
-            required=False,
-            description=''
-        ),
     }
 
 
-class Stead(ObjectBase):
-    """Объект участка."""
-
-    fields = {
-        'id': FieldDescriptor(
-            data_type=_int,
-            required=True,
-            description='Уникальный идентификатор записи дома',
-        ),
-        'obj_id': FieldDescriptor(
-            data_type=_int,
-            required=True,
-            description='Глобальный уникальный идентификатор дома',
-        ),
-        'guid': FieldDescriptor(
-            data_type=_uuid,
-            required=True,
-            description='UUID адресного объекта.',
-        ),
-        'ifns_fl_code': FieldDescriptor(
-            data_type=_unicode_or_empty,
-            required=False,
-            description='Код ИФНС для физических лиц.',
-        ),
-        'ifns_fl_territorial_district_code': FieldDescriptor(
-            data_type=_unicode_or_empty,
-            required=False,
-            description='Код территориального участка ИФНС ФЛ.',
-        ),
-        'ifns_ul_code': FieldDescriptor(
-            data_type=_unicode_or_empty,
-            required=False,
-            description='Код ИФНС для юридических лиц.',
-        ),
-        'ifns_ul_territorial_district_code': FieldDescriptor(
-            data_type=_unicode_or_empty,
-            required=False,
-            description='Код территориального участка ИФНС ЮЛ.',
-        ),
-        'okato': FieldDescriptor(
-            data_type=_unicode_or_empty,
-            required=False,
-            description='ОКАТО.',
-        ),
-        'oktmo': FieldDescriptor(
-            data_type=_unicode_or_empty,
-            required=False,
-            description='ОКТМО.',
-        ),
-        'postal_code': FieldDescriptor(
-            data_type=_unicode_or_empty,
-            required=False,
-            description='Почтовый индекс',
-        ),
-        'level': FieldDescriptor(
-            data_type=partial(_choices, GAR_LEVELS, _int),
-            required=True,
-            description='Уровень объекта.',
-        ),
-        'number': FieldDescriptor(
-            data_type=_unicode,
-            required=True,
-            description='Номер',
-        ),
-        'date_of_creation': FieldDescriptor(
-            data_type=_date,
-            required=True,
-            description='Начало действия записи',
-        ),
-        'date_of_update': FieldDescriptor(
-            data_type=_date,
-            required=True,
-            description='Дата  внесения (обновления) записи',
-        ),
-        'date_of_end': FieldDescriptor(
-            data_type=_date,
-            required=True,
-            description='Окончание действия записи',
-        ),
-        'region_code': FieldDescriptor(
-            data_type=_int,
-            required=True,
-            description='Код региона',
-        ),
-        'adm_parent_obj_id': FieldDescriptor(
-            data_type=_int,
-            required=False,
-            description='Родительский obj_id в административной иерархии'
-        ),
-        'adm_parent_guid': FieldDescriptor(
-            data_type=_uuid,
-            required=False,
-            description='Родительский guid в административной иерархии'
-        ),
-        'mun_parent_obj_id': FieldDescriptor(
-            data_type=_int,
-            required=False,
-            description='Родительский obj_id в муниципальной иерархии'
-        ),
-        'mun_parent_guid': FieldDescriptor(
-            data_type=_uuid,
-            required=False,
-            description='Родительский guid в муниципальной иерархии'
-        ),
-    }
-
-
-class Apartment(ObjectBase):
-    """Объект помещения."""
-
-    fields = {
-        'id': FieldDescriptor(
-            data_type=_int,
-            required=True,
-            description='Уникальный идентификатор записи дома',
-        ),
-        'obj_id': FieldDescriptor(
-            data_type=_int,
-            required=True,
-            description='Глобальный уникальный идентификатор дома',
-        ),
-        'guid': FieldDescriptor(
-            data_type=_uuid,
-            required=True,
-            description='UUID адресного объекта.',
-        ),
-        'number': FieldDescriptor(
-            data_type=_unicode,
-            required=True,
-            description='Номер',
-        ),
-        'apart_type': FieldDescriptor(
-            data_type=_unicode,
-            required=True,
-            description='Номер',
-        ),
-        'level': FieldDescriptor(
-            data_type=partial(_choices, GAR_LEVELS, _int),
-            required=True,
-            description='Уровень объекта.',
-        ),
-        'adm_parent_obj_id': FieldDescriptor(
-            data_type=_int,
-            required=False,
-            description='Родительский obj_id в административной иерархии'
-        ),
-        'adm_parent_guid': FieldDescriptor(
-            data_type=_uuid,
-            required=False,
-            description='Родительский guid в административной иерархии'
-        ),
-        'mun_parent_obj_id': FieldDescriptor(
-            data_type=_int,
-            required=False,
-            description='Родительский obj_id в муниципальной иерархии'
-        ),
-        'mun_parent_guid': FieldDescriptor(
-            data_type=_uuid,
-            required=False,
-            description='Родительский guid в муниципальной иерархии'
-        ),
-    }
-
-
-class ObjectMapper(with_metaclass(ABCMeta, MutableMapping)):
-    """Обертка над словарями, преобразующая ключи."""
+class ObjectMapper(MutableMapping, metaclass=ABCMeta):
+    """
+    Обертка над словарями, преобразующая ключи.
+    """
 
     @abstractproperty
     def fields_map(self):
-        """Список соответствия ключей."""
+        """Список соответствия ключей.
+
+        :rtype: dict
+        """
 
     def __init__(self, data):  # pylint: disable=super-init-not-called
         assert isinstance(data, dict), type(data)
@@ -712,7 +535,7 @@ class ObjectMapper(with_metaclass(ABCMeta, MutableMapping)):
     def __len__(self):
         i = 0
 
-        for i, _ in enumerate(iterkeys(self), 1):
+        for i, _ in enumerate(self.keys(), 1):
             pass
 
         return i
