@@ -1,28 +1,39 @@
 # coding: utf-8
-from __future__ import absolute_import
-from __future__ import unicode_literals
-
 import json
 import warnings
 
-from m3_ext.ui.base import BaseExtComponent
-from m3_ext.ui.containers.containers import ExtContainer
-from m3_ext.ui.fields.simple import ExtComboBox
-from m3_ext.ui.fields.simple import ExtHiddenField
-from m3_ext.ui.fields.simple import ExtStringField
-from m3_ext.ui.fields.simple import ExtTextArea
-from m3_ext.ui.misc.store import ExtJsonStore
+from m3_ext.ui.base import (
+    BaseExtComponent
+)
+from m3_ext.ui.containers.containers import (
+    ExtContainer
+)
+from m3_ext.ui.fields.simple import (
+    ExtComboBox,
+    ExtHiddenField,
+    ExtStringField,
+    ExtTextArea
+)
+from m3_ext.ui.misc.store import (
+    ExtJsonStore
+)
+from m3_gar_constants import (
+    UI_LEVEL_FLAT,
+    UI_LEVEL_HOUSE,
+    UI_LEVEL_PLACE,
+    UI_LEVEL_STREET,
+    UI_LEVELS
+)
 
-from m3_gar_constants import UI_LEVEL_FLAT
-from m3_gar_constants import UI_LEVEL_HOUSE
-from m3_gar_constants import UI_LEVEL_PLACE
-from m3_gar_constants import UI_LEVEL_STREET
-from m3_gar_constants import UI_LEVELS
-from m3_gar_client.data import ObjectDictAdapter
-from m3_gar_client.data import ObjectMapper
-from m3_gar_client.utils import cached_property
-from m3_gar_client.utils import get_address_object
-from m3_gar_client.utils import get_house
+from m3_gar_client.data import (
+    ObjectDictAdapter,
+    ObjectMapper
+)
+from m3_gar_client.utils import (
+    cached_property,
+    get_address_object,
+    get_house
+)
 import m3_gar_client
 
 
@@ -353,7 +364,7 @@ class AddressFields(BaseExtComponent):
             name=self._names_of_fields['house_id'],
         )
 
-#TODO BOBUH-20190 возможно, от этого стоит отказаться или, наоборот, сделать более общим
+    # TODO: BOBUH-20190 возможно, от этого стоит отказаться или, наоборот, сделать более общим
     @cached_property
     def field__house_type(self):
         """
