@@ -1,17 +1,23 @@
 # coding: utf-8
-from __future__ import absolute_import
-from __future__ import unicode_literals
+from importlib import (
+    reload
+)
+import sys
 
+from django.conf import (
+    settings
+)
+from django.urls.base import (
+    clear_url_caches
+)
 from m3_gar_constants import (
     GAR_HIERARCHIES,
-    GAR_HIERARCHY_MUN,
+    GAR_HIERARCHY_MUN
 )
 
 from m3_gar_client.data import (
     AddressObject,
-    Apartment,
-    House,
-    Stead,
+    House
 )
 
 
@@ -95,7 +101,7 @@ def find_address_objects(filter_string, levels=None, typenames=None, parent_id=N
     :rtype: generator
     """
     from m3_gar_client import (
-        config,
+        config
     )
 
     return config.backend.find_address_objects(filter_string, levels, typenames, parent_id, timeout)
@@ -110,7 +116,7 @@ def get_address_object(obj_id, timeout=None):
     :rtype: m3_gar_client.data.AddressObject or NoneType
     """
     from m3_gar_client import (
-        config,
+        config
     )
 
     return config.backend.get_address_object(obj_id, timeout)
@@ -129,7 +135,7 @@ def find_house(house_number='', parent_id=None, building_number=None, structure_
     :rtype: m3_gar_client.data.House or NoneType
     """
     from m3_gar_client import (
-        config,
+        config
     )
 
     return config.backend.find_house(house_number, parent_id, building_number, structure_number, timeout)
@@ -150,7 +156,7 @@ def get_house(house_id, timeout=None):
     :rtype: m3_gar_client.data.House
     """
     from m3_gar_client import (
-        config,
+        config
     )
 
     return config.backend.get_house(house_id, timeout)
@@ -167,7 +173,7 @@ def get_stead(stead_id, timeout=None):
         Объект m3_gar_client.data.House
     """
     from m3_gar_client import (
-        config,
+        config
     )
 
     return config.backend.get_stead(stead_id, timeout)
@@ -268,7 +274,7 @@ def get_full_details(obj, hierarchy=GAR_HIERARCHY_MUN, timeout=None):
     """
     Возвращает полный список объектов, снизу вверх из иерархии.
     """
-    if not isinstance(obj, (Apartment, Stead, House, AddressObject)):
+    if not isinstance(obj, (House, AddressObject)):
         raise TypeError(obj)
 
     if hierarchy not in GAR_HIERARCHIES:
@@ -278,14 +284,7 @@ def get_full_details(obj, hierarchy=GAR_HIERARCHY_MUN, timeout=None):
 
     objects = []
 
-    if isinstance(obj, Apartment):
-        objects.append(obj)
-
-        parent_id = getattr(obj, parent_attr)
-        if parent_id:
-            obj = get_house(parent_id, timeout)
-
-    if isinstance(obj, (House, Stead)):
+    if isinstance(obj, House):
         objects.append(obj)
 
         parent_id = getattr(obj, parent_attr)
@@ -313,3 +312,13 @@ def get_details(obj, timeout=None):
     result = get_full_details(obj, timeout=timeout)
 
     return result[1:] if len(result) > 1 else result
+
+
+def reload_urlconf(urlconf=None):
+    """Перезагрузка Django urlconf."""
+
+    urlconf = urlconf or settings.ROOT_URLCONF
+    assert urlconf is not None
+
+    if urlconf in sys.modules:
+        clear_url_caches()
